Affair class

Financial data download and parsing API.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fetch({required String downloadDir, required String filename, void onProgress(int count, int blockSize)?}) Future<bool>
Download a single financial data file.
fetchAll({required String downloadDir}) Future<void>
Download all financial data files.
files() Future<Uint8List>
Get list of available financial files. Returns raw bytes from the server.