TransactionData class

Transaction tick data.

Constructors

TransactionData({required String time, required double price, required double vol, required double amount, required int buySell})
const
TransactionData.fromJson(Map<String, dynamic> json)
factory

Properties

amount double
final
buySell int
final
hashCode int
The hash code for this object.
no setterinherited
price double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String
final
vol double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited