StockQuote class

Real-time stock quote data.

Constructors

StockQuote({required int market, required String code, required int active1, required double price, required double lastClose, required double open, required double high, required double low, required String serverTime, required double vol, required double curVol, required double amount, required double bid1, required double ask1, required double bidVol1, required double askVol1, required double bid2, required double ask2, required double bidVol2, required double askVol2, required double bid3, required double ask3, required double bidVol3, required double askVol3, required double bid4, required double ask4, required double bidVol4, required double askVol4, required double bid5, required double ask5, required double bidVol5, required double askVol5, required double speed})
const
StockQuote.fromJson(Map<String, dynamic> json)
factory

Properties

active1 int
final
amount double
final
ask1 double
final
ask2 double
final
ask3 double
final
ask4 double
final
ask5 double
final
askVol1 double
final
askVol2 double
final
askVol3 double
final
askVol4 double
final
askVol5 double
final
bid1 double
final
bid2 double
final
bid3 double
final
bid4 double
final
bid5 double
final
bidVol1 double
final
bidVol2 double
final
bidVol3 double
final
bidVol4 double
final
bidVol5 double
final
code String
final
curVol double
final
hashCode int
The hash code for this object.
no setterinherited
high double
final
lastClose double
final
low double
final
market int
final
open double
final
price double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverTime String
final
speed double
final
vol double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited