Quotes class

Quotes API factory.

// Standard market (股票)
final quotes = await Quotes.factory(market: 'std');

// Extended market (扩展市场)
final quotes = await Quotes.factory(market: 'ext');

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

factory({String market = 'std', String? host, int? port, bool autoRetry = true, Duration timeout = const Duration(seconds: 15)}) Future
Create a Quotes instance. market - 'std' for standard market (stocks), 'ext' for extended market.