Reader class

Reader API factory for offline TDX data files.

final reader = Reader.factory(market: 'std', tdxDir: '/path/to/tdx');
final bars = reader.daily('600036');

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

factory({String market = 'std', required String tdxDir}) → dynamic
Create a Reader instance. market - 'std' for standard market, 'ext' for extended market. tdxDir - path to TDX installation directory.